@@ -87,14 +87,12 @@ class GSPeerConnectionBroadcaster:
 
             @self.sio.event
             async def watcher(id):
-                # if len(rtconfiList) > 0:
-                pc = RTCPeerConnection(configuration=RTCConfiguration([
-                    RTCIceServer(self.gsdbs.credentials["turnserver"],
-                                 self.gsdbs.credentials["turnuser"],
-                                 self.gsdbs.credentials["turnpw"])
-                ]))
-                # else:
-                # pc = RTCPeerConnection()
+                if len(self.rtconfiList) > 0:
+                    pc = RTCPeerConnection(configuration=RTCConfiguration(
+                        self.rtconfiList
+                    ))
+                else:
+                    pc = RTCPeerConnection()
 
                 self.peerConnections[id] = pc
 
